#!/bin/bash

DBUS_PATH=$1

function main() {
    local str="This tool is designed to remove the read-only permission from the disk, and it carries certain risks. Do you wish to proceed with the execution?"
    local tr_str
    tr_str=$(Translate "${str}")

    local select
    select=$(ShowConfirmBox "${DBUS_PATH}" "${tr_str}" "question")
    if [ "${select}" == "no" ]; then
        exit 255
    fi

    local ro_dev
    ro_dev=$(mount | grep "ro," | grep -v "tmpfs" | grep -v "remount-ro" | grep -v squashfs | grep -v nvme | awk '{print $1}')
    if [ "${ro_dev}" == "" ]; then
        local str="No disk with read-only access has been found"
        local tr_str
        tr_str=$(Translate "${str}")
        ShowMessageBox "${DBUS_PATH}" "${tr_str}" "info"
        exit 1
    fi

    for dev in ${ro_dev}; do
        local str="Commencing the removal of read-only access from the disk"
        local tr_str
        tr_str=$(Translate "${str}")
        echo "[${dev}]: ${tr_str}"

        local mount_point
        mount_point=$(df -h | grep "${dev}" | awk '{print $6}')
        SudoWrapper -s "mount -o remount,rw ${mount_point}"
        if [ $? == 0 ]; then
            str="The read-only access to the disk has been successfully removed"
            tr_str=$(Translate "${str}")
            echo "[${dev}]: ${tr_str}"
        else
            str="The attempt to remove the read-only access from the disk has failed"
            tr_str=$(Translate "${str}")
            echo "[${dev}]: ${tr_str}"
        fi
    done

    local str="The issue has been successfully resolved"
    local tr_str
    tr_str=$(Translate "${str}")
    ShowMessageBox "${DBUS_PATH}" "${tr_str}" "info"
}

main
exit 0
